##  Editing in the Report
Each of the items in the timeline can be interacted with via the Edit Pane which allows you to directly change some Fact Sheet field values without leaving the report. In order to access the edit pane in a Landscape report, select any of the Fact Sheets, that is click on the one that requires modification. A pane will appear on the right-hand side, displaying information about the Fact Sheet and offering the ability to edit its properties. You will also find details of Milestones in the edit pane. Any adjustments made are immediately implemented within both the report and the Fact Sheet itself. Alternatively, you can navigate to the source Fact Sheet by clicking on the Fact Sheet name in the edit pane.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274792377a4410148436e58fa7b3366b_LowRes.png)
The Roadmap Report allows users to analyze dependencies between different initiatives or projects. This can help organizations identify potential risks and make informed decisions about their IT investments.
You can show dependencies between Fact Sheets. This relies on the data you have in the Requires and Required by fields in the Fact Sheet. To show these two fields, you can enable the Dependencies section in your Fact Sheet, you can see the detail in [Meta Model Configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the meta model to adjust it to your requirements."). Once you have the relations between Fact Sheets, you can see this graph showing the dependencies, for example between these two Application Fact Sheets.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2742afce7a44101486a5f46f36fa34a0_LowRes.png)
